#include <hidef.h>					// common defines and macros */
#include "derivative.h"				// derivative-specific definitions */
#include "sci_hc12.h"				// sci routines

#define LED1	PTT_PTT2
#define LED2	PTT_PTT3
#define LED3	PTT_PTT4
#define LED4	PTT_PTT5

#define SW1		0x10
#define SW2		0x20
#define SW3		0x40
#define SW4		0x80

#define nON		0
#define nOFF	1


void CPMU_PEE_8MHz(void);			// setup clock
void ATD_EN(void);					// enable ATM module

void main(void) {

	byte n;
	
	DisableInterrupts;
	ATD_EN();							// enable ATD
	PTT = 0x3C;							//	init PTT[5:2] output
	DDRT = 0x3C;						//	PTT[5:2] output others input

	ATDDIEN = 0x00F0;					// enable sw input on PAD[7:4]   
	PER0AD = 0x80;						// enable PU on PAD15 to enable COM
	PER1AD = 0xF0;						// enable PBSW pulls
	PPS1AD = 0x00;						// pull-ups applied

	PTM = 0x02;							// init PORT M
	DDRM = 0x03;						// PTM[1:0] output
		
	ensci();								// enable serial routines

	
	for(;;){
	
//Serial Test
		echo_com();						// echo keybd data

//PBSW & LED Test
		n = PT1AD;						// get PBSW input
		switch(n) {
			case 0xEF:{					// SW1 pressed
				LED1 ^= 1;				// toggle LED1
				while((PT1AD & SW1) == 0);	// wait for PBSW release
				break;
			}
			case 0xDF:{					// SW2 pressed
				LED2 ^= 1;				// toggle LED2
				while((PT1AD & SW2) == 0);	// wait for PBSW release
				break;
			}
			case 0xBF:{					// SW1 pressed
				LED3 ^= 1;				// toggle LED3
				while((PT1AD & SW3) == 0);	// wait for PBSW release
				break;
			}
			case 0x7F:{					// SW1 pressed
				LED4 ^= 1;				// toggle LED4
				while((PT1AD & SW4) == 0);	// wait for PBSW release
				break;
			}
			default:
				break;
		}
	}
}

/**********************************************************
*	CPMU_PEE_8MHz
*
*	Setup clock module for PLL Engaged using External XTAL
*	For 8MHz XTAL - 
*	VCOCLK - 64MHz, Core Clk - 16MHz, Bus Clk - 8MHz
**********************************************************/
void CPMU_PEE_8MHz(void){

	CPMUSYNR = 0x01;					// fVCO = 32MHz
	CPMUREFDIV = 0x80;				// OSC input is 8MHz
	CPMUPOSTDIV = 0x01;				// core clk - 16MHz, bus clk - 8MHz
	
	CPMUOSC_OSCE = 1;					// enable ext OSC
	while(!CPMUFLG_UPOSC || !CPMUFLG_LOCK);
											// wait for ext osc to stabilize and pll to lock
	CPMUFLG = 0xFF;					// clear CMPMU int flags - not needed but good practice
}


/**********************************************************
*	ATD_EN
*
*	Configure ATD to sample CH0.  Write Channel Select Code
*	bits C[D:A] to start conversion sequence
**********************************************************/
void ATD_EN(void){

	ATDCTL1_SRES = 0;					// 8 bit results
	ATDCTL3_DJM = 1;					// right justified data
	ATDCTL4_PRS = 0;					// bus clk div 2, 4 clks per sample
	ATDSTAT0_SCF = 1;					// clear flag
}
